# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import redisgrpc.redislite_pb2 as redislite__pb2


class RedisLiteServerStub(object):
    """The greeting service definition.
    service Greeter {
    // Sends a greeting
    rpc SayHello (HelloRequest) returns (HelloReply) {}
    // Sends another greeting
    rpc SayHelloAgain (HelloRequest) returns (HelloReply) {}
    }

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.InitConnection = channel.unary_unary(
                '/redislite.RedisLiteServer/InitConnection',
                request_serializer=redislite__pb2.InitRequest.SerializeToString,
                response_deserializer=redislite__pb2.InitReply.FromString,
                )
        self.Set = channel.unary_unary(
                '/redislite.RedisLiteServer/Set',
                request_serializer=redislite__pb2.SetRequest.SerializeToString,
                response_deserializer=redislite__pb2.SetReply.FromString,
                )
        self.Get = channel.unary_unary(
                '/redislite.RedisLiteServer/Get',
                request_serializer=redislite__pb2.GetRequest.SerializeToString,
                response_deserializer=redislite__pb2.GetReply.FromString,
                )


class RedisLiteServerServicer(object):
    """The greeting service definition.
    service Greeter {
    // Sends a greeting
    rpc SayHello (HelloRequest) returns (HelloReply) {}
    // Sends another greeting
    rpc SayHelloAgain (HelloRequest) returns (HelloReply) {}
    }

    """

    def InitConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Set(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RedisLiteServerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'InitConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.InitConnection,
                    request_deserializer=redislite__pb2.InitRequest.FromString,
                    response_serializer=redislite__pb2.InitReply.SerializeToString,
            ),
            'Set': grpc.unary_unary_rpc_method_handler(
                    servicer.Set,
                    request_deserializer=redislite__pb2.SetRequest.FromString,
                    response_serializer=redislite__pb2.SetReply.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=redislite__pb2.GetRequest.FromString,
                    response_serializer=redislite__pb2.GetReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'redislite.RedisLiteServer', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RedisLiteServer(object):
    """The greeting service definition.
    service Greeter {
    // Sends a greeting
    rpc SayHello (HelloRequest) returns (HelloReply) {}
    // Sends another greeting
    rpc SayHelloAgain (HelloRequest) returns (HelloReply) {}
    }

    """

    @staticmethod
    def InitConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/redislite.RedisLiteServer/InitConnection',
            redislite__pb2.InitRequest.SerializeToString,
            redislite__pb2.InitReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Set(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/redislite.RedisLiteServer/Set',
            redislite__pb2.SetRequest.SerializeToString,
            redislite__pb2.SetReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/redislite.RedisLiteServer/Get',
            redislite__pb2.GetRequest.SerializeToString,
            redislite__pb2.GetReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: redislite.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fredislite.proto\x12\tredislite\"$\n\x0bInitRequest\x12\x15\n\rconnection_id\x18\x01 \x01(\t\"\x1b\n\tInitReply\x12\x0e\n\x06status\x18\x01 \x01(\t\"(\n\nSetRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x1a\n\x08SetReply\x12\x0e\n\x06status\x18\x01 \x01(\t\"\x19\n\nGetRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\")\n\x08GetReply\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t2\xbd\x01\n\x0fRedisLiteServer\x12@\n\x0eInitConnection\x12\x16.redislite.InitRequest\x1a\x14.redislite.InitReply\"\x00\x12\x33\n\x03Set\x12\x15.redislite.SetRequest\x1a\x13.redislite.SetReply\"\x00\x12\x33\n\x03Get\x12\x15.redislite.GetRequest\x1a\x13.redislite.GetReply\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'redislite_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_INITREQUEST']._serialized_start=30
  _globals['_INITREQUEST']._serialized_end=66
  _globals['_INITREPLY']._serialized_start=68
  _globals['_INITREPLY']._serialized_end=95
  _globals['_SETREQUEST']._serialized_start=97
  _globals['_SETREQUEST']._serialized_end=137
  _globals['_SETREPLY']._serialized_start=139
  _globals['_SETREPLY']._serialized_end=165
  _globals['_GETREQUEST']._serialized_start=167
  _globals['_GETREQUEST']._serialized_end=192
  _globals['_GETREPLY']._serialized_start=194
  _globals['_GETREPLY']._serialized_end=235
  _globals['_REDISLITESERVER']._serialized_start=238
  _globals['_REDISLITESERVER']._serialized_end=427
# @@protoc_insertion_point(module_scope)



#  /*
#   * MIT License
#   *
#   * Copyright (c) 2024 Gautam Sharma
#   *
#   * Permission is hereby granted, free of charge, to any person obtaining a copy
#   * of this software and associated documentation files (the "Software"), to deal
#   * in the Software without restriction, including without limitation the rights
#   * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#   * copies of the Software, and to permit persons to whom the Software is
#   * furnished to do so, subject to the following conditions:
#   *
#   * The above copyright notice and this permission notice shall be included in all
#   * copies or substantial portions of the Software.
#   *
#   * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#   * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#   * SOFTWARE.
#   */

#
# Created by Gautam Sharma on 2/19/24.
#


import grpc
import redisgrpc.redislite_pb2 as redislite_pb2
import redisgrpc.redislite_pb2_grpc as redislite_pb2_grpc

class Client:
    def __init__(self, port):
        self.port = port

    def init_connection(self):
        with grpc.insecure_channel("localhost:{}".format(self.port)) as channel:
            try:
                stub = redislite_pb2_grpc.RedisLiteServerStub(channel)
                # Generate random strings 200 times
                response = stub.InitConnection(redislite_pb2.InitRequest(connection_id="0.0.0.0:{}".format(self.port)))
                print("redis client status: " + response.status)
            except:
                print("Server not started");
                return

    def set(self, key, value):
        with grpc.insecure_channel("localhost:{}".format(self.port)) as channel:
            try:
                stub = redislite_pb2_grpc.RedisLiteServerStub(channel)
                # Generate random strings 200 times
                response = stub.Set(redislite_pb2.SetRequest(key=key, value=value))
                print("redis client status: " + response.status)
            except:
                print("Server not started");
                return

    def get(self, key):
        with grpc.insecure_channel("localhost:{}".format(self.port)) as channel:
            try:
                stub = redislite_pb2_grpc.RedisLiteServerStub(channel)
                # Generate random strings 200 times
                response = stub.Get(redislite_pb2.GetRequest(key=key))
                print("redis client status: " + response.status)
                if(response.status == "REDISLITE_OK"):
                    print("Got value " + response.status)
                    return response.value
                else:
                    print("Key not found")

            except:
                print("Server not started");
                return


#  /*
#   * MIT License
#   *
#   * Copyright (c) 2024 Gautam Sharma
#   *
#   * Permission is hereby granted, free of charge, to any person obtaining a copy
#   * of this software and associated documentation files (the "Software"), to deal
#   * in the Software without restriction, including without limitation the rights
#   * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#   * copies of the Software, and to permit persons to whom the Software is
#   * furnished to do so, subject to the following conditions:
#   *
#   * The above copyright notice and this permission notice shall be included in all
#   * copies or substantial portions of the Software.
#   *
#   * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#   * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#   * SOFTWARE.
#   */

# Import necessary modules/classes from your package

# Optionally, you can define __all__ to specify what gets imported when using 'from package import *'
__all__ = ['redisgrpc.py']

# Optionally, if you want to specify the version of your package
__version__ = '1.0.0'


from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class InitRequest(_message.Message):
    __slots__ = ("connection_id",)
    CONNECTION_ID_FIELD_NUMBER: _ClassVar[int]
    connection_id: str
    def __init__(self, connection_id: _Optional[str] = ...) -> None: ...

class InitReply(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: str
    def __init__(self, status: _Optional[str] = ...) -> None: ...

class SetRequest(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: str
    def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...

class SetReply(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: str
    def __init__(self, status: _Optional[str] = ...) -> None: ...

class GetRequest(_message.Message):
    __slots__ = ("key",)
    KEY_FIELD_NUMBER: _ClassVar[int]
    key: str
    def __init__(self, key: _Optional[str] = ...) -> None: ...

class GetReply(_message.Message):
    __slots__ = ("status", "value")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    status: str
    value: str
    def __init__(self, status: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...



#  /*
#   * MIT License
#   *
#   * Copyright (c) 2024 Gautam Sharma
#   *
#   * Permission is hereby granted, free of charge, to any person obtaining a copy
#   * of this software and associated documentation files (the "Software"), to deal
#   * in the Software without restriction, including without limitation the rights
#   * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#   * copies of the Software, and to permit persons to whom the Software is
#   * furnished to do so, subject to the following conditions:
#   *
#   * The above copyright notice and this permission notice shall be included in all
#   * copies or substantial portions of the Software.
#   *
#   * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#   * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#   * SOFTWARE.
#   */

from setuptools import setup, find_packages
# read the contents of your README file
from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name='redisgrpc',
    version='0.2',
    packages=find_packages(),
    description='A small production ready client library that emulates redis and used gRPC for communication',
    author='Gautam Sharma',
    install_requires=[
        'grpcio-tools'
    ],
    long_description=long_description,
    long_description_content_type='text/markdown',
    keywords=['redis', 'gRPC'],
    author_email='gautamsharma2813@gmail.com',
    url='https://github.com/gautam-sharma1/redisgrpc',
    classifiers=[
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)